Li Ruofan 201199450

Dependencies:   mbed Gamepad Joystick

Revision:
8:b4a2954dd74f
Parent:
6:cbd9e1f26a10
diff -r e3844250b77d -r b4a2954dd74f shot/shot.h
--- a/shot/shot.h	Fri May 15 22:23:22 2020 +0000
+++ b/shot/shot.h	Sat May 16 17:26:10 2020 +0000
@@ -1,43 +1,43 @@
-#ifndef BULLET_H
-#define BULLET_H
+#ifndef Shot_H
+#define Shot_H
 
 #include "mbed.h"
 #include "N5110.h"
 #include "Joystick.h"
 #include "Bitmap.h"
-/** Bullet Class
-@brief Library for one of the objects bullet of star war, University of Leeds
-@author Huang Xinjie
-@date May 2019
+/** Shot Class
+@brief Library for one of the objects Shot of spaceship, University of Leeds
+@author Li Ruofan
+@date May 2020
 */
 
-class Bullet{
+class Shot{
 
 public:
     /** Constructor */
-    Bullet();
+    Shot();
     
     /** Destructor */
-    ~Bullet();
+    ~Shot();
     
     /** Initialize the position and the size of the bullet
      * @param the value of horizontal position x (int)
      * @param the value of vertical position x (int)
      * @param the number of columns of bullet image (int)
      * @param the number of rows of bullet image (int) 
      */
     void init(int x,int y,int sizeX,int sizeY);
     
     /** draw the image of the bullet
      * @param lcd (N5110)
      */
-    void draw(N5110 &lcd);  //draw the bullet
+    void draw(N5110 &lcd);  //draw the Shot
     
     /** Update the position of the bullet */   
     void update();
     
     /** get the position of bullet in the lcd
      * @return the current postion of bullet
      */ 
     Vector2D getPos();
 private:
@@ -1,43 +1,43 @@
     
-    /** Initialize the position and the size of the bullet
+    /** Initialize the position and the size of the Shot
      * @param the value of horizontal position x (int)
      * @param the value of vertical position x (int)
@@ -1,43 +1,43 @@
      * @param the value of horizontal position x (int)
      * @param the value of vertical position x (int)
-     * @param the number of columns of bullet image (int)
-     * @param the number of rows of bullet image (int) 
+     * @param the number of columns of Shot image (int)
+     * @param the number of rows of Shot image (int) 
      */
     void init(int x,int y,int sizeX,int sizeY);
@@ -1,43 +1,43 @@
     void init(int x,int y,int sizeX,int sizeY);
     
-    /** draw the image of the bullet
+    /** draw the image of the Shot
      * @param lcd (N5110)
      */
@@ -1,43 +1,43 @@
     
-    /** Update the position of the bullet */   
+    /** Update the position of the Shot */   
     void update();
     
@@ -1,43 +1,43 @@
     void update();
     
-    /** get the position of bullet in the lcd
-     * @return the current postion of bullet
+    /** get the position of Shot in the lcd
+     * @return the current postion of Shot
      */ 
     Vector2D getPos();